@@ -9,9 +9,9 @@ import requests
 from tqdm import tqdm
 from tqdm.utils import CallbackIOWrapper
 
-from .errors import AbortError
-from .s3 import get_real_url, reserve_url
-from .util import generate_token
+from todus3.errors import AbortError
+from todus3.s3 import get_real_url, reserve_url
+from todus3.util import generate_token
 
 DEFAULT_TIMEOUT = 60 * 2  # 2 minutes
 CHUNK_SIZE = 1024
@@ -166,7 +166,10 @@ class ToDusClient:
         url = "https://auth.todus.cu/v2/auth/token"
         with self.session.post(url, data=data, headers=headers) as resp:
             resp.raise_for_status()
-            token = "".join([c for c in resp.text if c in string.printable])
+            # Default Encoding for HTML4 ISO-8859-1 (Latin-1)
+            token = "".join(
+                c for c in resp.content.decode("latin-1") if c in string.printable
+            )
 
         return token
 
@@ -258,11 +261,11 @@ class ToDusClient:
 
             overwrite = file_save.stat().st_size < size if file_save.exists() else True
             if overwrite:
+                print(f"{file_save.name}:")
                 with tqdm.wrapattr(
                     open(file_save, "wb"),
                     "write",
                     miniters=1,
-                    desc=file_save.name,
                     total=size,
                     unit="B",
                     unit_scale=True,
